pub struct Valid<T>where
T: Validate,{ /* private fields */ }Expand description
A wrapper of T that validate the state of T every time accessing it.
- It validates the state before accessing it, i.e., if when a invalid state is written to it, it won’t panic until next time accessing it.
- The validation is turned on only when
debug_assertionsis enabled.
An example of defining field a whose value must not exceed 10.
ⓘ
struct Foo { a: u64 }
impl Validate for Foo {
fn validate(&self) -> Result<(), Box<dyn Error>> {
less_equal!(self.a, 10);
Ok(())
}
}
let f = Valid::new(Foo { a: 20 });
let _x = f.a; // panic: panicked at 'invalid state: expect: self.a(20) <= 10(10) ...Validation is triggered when:
DereforDerefMutis called. This is the major use case.Cloneis called.PartialEqorEqis called.PartialOrdorOrdis called.Hashis called.
Validation is not triggered when:
Copy: Because it is just a byte copy.DebugandDisplay: for being able to examine the value for debugging.
Implementations
Sourceimpl<T: Validate> Valid<T>
impl<T: Validate> Valid<T>
Sourcepub fn enable_validation(&mut self, enabled: bool)
pub fn enable_validation(&mut self, enabled: bool)
Set whether to validate the state when accessing it.
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Get whether to validate the state when accessing it.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume self and return the wrapped value.
This does NOT validate the state.